/**
 * Ajax call
 */
var ajax = {
	timeout: null,
	httpReq: null,
	doRequest: function(options, successCallbackFunction, errorCallbackFunction) {
		logger.debug('ajax.doRequest');
		if (typeof options.url == 'undefined') {
			logger.error("You have to defined 'options.url'.");
			return false;
		}

		var method = (typeof options.method != 'undefined') ? options.method.toUpperCase() : 'GET';
		var url = options.url;

		if (method !== 'POST' && method !== 'GET') {
			logger.error("Method '" + method + "' not supported.");
			return false;
		}

		var params = null;
		if (typeof options.data != 'undefined') {
			params = options.data.join("&");

			if (method === 'GET' && params != '') {
				if (url.indexOf('?') != -1) {
					url+= '&' + params;
				} else {
					url+= '?' + params;
				}
				params = null;
			}
		}
		logger.debug(url);
		this.reset();

	    this.httpReq = new Ajax();

	    var self = this;
	    this.httpReq.onreadystatechange = function() {
			self.readyStateChanged(successCallbackFunction, errorCallbackFunction);
		};

	    this.httpReq.open(method, url, true);
	    this.httpReq.send(params);
		this.timeout = setTimeout(function() {
			logger.error('httpRequest timeout');
			self.reset();
			errorCallbackFunction();
		}, AJAX_TIMEOUT);
	},
	readyStateChanged: function(successCallbackFunction, errorCallbackFunction) {
		logger.debug('ajax.readyStateChanged');
		logger.info('readyState : ' + this.httpReq.readyState);
		if (this.httpReq.readyState == 4) {
			this.clearTimeout();
			try {
				var responseStatus = this.httpReq.status;
			} catch (e) {
				if (typeof errorCallbackFunction == 'function') {
					errorCallbackFunction();
				}
				return false;
			}
			if (typeof successCallbackFunction == 'function') {
				successCallbackFunction(this.httpReq);
			}
		}
	},
	clearTimeout: function() {
		logger.debug('ajax.clearTimeout');
		if (this.timeout !== null) {
			clearTimeout(this.timeout);
			this.timeout = null;
		}
	},
	clearHttpReq: function() {
		logger.debug('ajax.clearHttpReq');
		if (this.httpReq !== null) {
			if (typeof this.httpReq.abort === 'function') {
				this.httpReq.abort();
			}
			this.httpReq = null;
		}
	},
	reset: function() {
		logger.debug('ajax.reset');
		this.clearTimeout();
		this.clearHttpReq();
	}
}
