/* 
 * JS File for Actualite View
 */
var aroundMeScreen = {
	latitude: null,
	longitude: null,
	doRequest: true,
	onActivate: function(zipCode) {
		logger.debug('aroundMeScreen.onActivate');
		loader.show();
		this.page = 1;
		this.members = [];
		this.zipCode = zipCode;
		this.lastZipCodeSelected = zipCode;
		aroundMeScreen.hideMoreMembersButton();
		this.loadData();
	},
	onDeactivate: function() {
		logger.debug('aroundMeScreen.onDeactivate');
		aroundMeScreen.doRequest = true;
	},
	loadGeolocation: function() {
		loader.show();
		var serviceObj = null;
		var positionOpts = {
        	timeout: 30000,
        	maximumAge: 1000
    	};
    	try {
        	serviceObj = nokia.device.load("geolocation");
        	serviceObj.getCurrentPosition(aroundMeScreen.successLoadGeolocation, aroundMeScreen.errorLoadGeolocation, positionOpts);
    	} 
		catch (e) {
        	aroundMeScreen.errorLoadZipCodes("GetLocation error : " + e.message);
			return false;
    	}
	},
	successLoadGeolocation: function(position) {
		aroundMeScreen.longitude = position.coords.longitude;
		aroundMeScreen.latitude = position.coords.latitude;
		aroundMeScreen.loadZipCodes();
	},
	errorLoadGeolocation: function() {
		aroundMeScreen.errorLoadZipCodes("GetLocation error : " + e.message);
		return false;
	},
	loadZipCodes: function() {
		logger.debug('aroundMeScreen.loadZipCodes');
		logger.debug('latitude => ' + aroundMeScreen.latitude);
		logger.debug('longitude => ' + aroundMeScreen.longitude);
		var options = {
			method: 'GET',
			ws: 'geo.findcitiesaroundcoordinates',
			data: [
				'latitude=' + aroundMeScreen.latitude,
				'longitude=' + aroundMeScreen.longitude,
				'country=' + COUNTRY,
				'distance=10'
			]
		}
		ws.doRequest(options, this.successLoadZipCodes, this.errorLoadZipCodes);
	},
	successLoadZipCodes: function(httpReq) {
		logger.debug('aroundMeScreen.successLoadZipCodes');

		if (httpReq.responseText !== '') {
			// Eval response to transform json to an object
			try {
				var response = eval('(' + httpReq.responseText + ')');
			} catch(exception) {
				aroundMeScreen.errorLoadZipCodes('eval of httpReq.responsetext failed');
				return false;
			}

			if (typeof response.resultset.result != 'undefined') {
				if (response.resultset.result.zip_codes.length == 0) {
					aroundMeScreen.errorLoadZipCodes('response.resultset.result is empty');
				} else {
					aroundMeScreen.createZipCodesPopup(response.resultset.result.zip_codes);
				}
				return true;
			} else {
				aroundMeScreen.errorLoadZipCodes('response.resultset.result is undefined');
				return false;
			}
		} else {
			aroundMeScreen.errorLoadZipCodes('httpReq.responseText is empty');
			return false;
		}
	},
	errorLoadZipCodes: function(errorCode) {
		logger.debug('aroundMeScreen.errorLoadZipCodes');
		logger.error(errorCode);
		loader.hide();
		confirmation.alert("confirmationPopupText", stringTable.code.loadGeolocError);
	},
	createZipCodesPopup: function(zipCodes) {
		logger.debug('aroundMeScreen.createZipCodesPopup');
		var html = '<ul>';
		for (var i = 1, length = zipCodes.length; i <= length; i++) {
			var classname = i%2 == 0 ? "even" : "odd";
			var zipCode = zipCodes[i - 1];
			html+= '<li class="' + classname + '" onclick="helper.changePage(\'aroundMe\', ' + zipCode + ')">' + zipCode + '</li>';
		}
		html+= '</ul>';

		document.getElementById('zipCodesPopupContainer').innerHTML = html;
		this.zipCodesPopup = new popup('zipCodesPopup', 'zipCodeMenuClose');
		loader.hide();
		this.zipCodesPopup.show();
	},
	loadData: function(viewCode) {
		logger.debug('aroundMeScreen.loadData');
		this.zipCodesPopup.hide();
		loader.show();
		var options = {
			method: 'GET',
			ws: 'search.advancedsearch',
			data: [
				'kvk=' + user.my_gender + user.my_search_gender,
				'postcode=' + aroundMeScreen.zipCode,
				'online=1',
				'distance=10',
				'country=' + COUNTRY
			]
		};
		if (typeof viewCode !== 'undefined') {
			options.data.push('ref=' + viewCode);
		}
		if (aroundMeScreen.doRequest) {
			ws.doRequest(options, aroundMeScreen.successLoadData, aroundMeScreen.errorLoadData);
		} else {
			// used when back button is triggered
			loader.hide();
			return true;
		}
	},
	successLoadData: function(httpReq) {
		logger.debug('aroundMeScreen.successLoadData');
		if (httpReq.responseText !== '') {
			try {
				var response = eval('(' + httpReq.responseText + ')');
			} catch(exception) {
				aroundMeScreen.errorLoadData('wsResponseUnavailable');
				return false;
			}

			if (typeof response.resultset.result != 'undefined') {
				if (aroundMeScreen.page > 6) {
					aroundMeScreen.members = [];
				}
				aroundMeScreen.members.push(response.resultset.result.members);
				if (response.resultset.result.navigate.after !== null && aroundMeScreen.page <= 5) {
					aroundMeScreen.page++;
					aroundMeScreen.loadData(response.resultset.result.navigate.after[0].ref);
				} else {
					// Display more button
					if (response.resultset.result.navigate.after !== null) {
						aroundMeScreen.displayMoreMembersButton(response.resultset.result.navigate.after[0].ref);
					} else {
						aroundMeScreen.hideMoreMembersButton();
					}

					aroundMeScreen.createPage(aroundMeScreen.members);
				}
				return true;
			} else {
				aroundMeScreen.errorLoadData('wsResponseUnavailable');
				return false;
			}
		} else {
			aroundMeScreen.errorLoadData('wsResponseUnavailable');
			return false;
		}
	},
	errorLoadData: function(errorCode) {
		logger.debug('aroundMeScreen.errorLoadData');
		logger.error(errorCode);
		loader.hide();
		confirmation.alert("confirmationPopupText", stringTable.code.loadError);
	},
	createPage: function(members) {
		logger.debug('aroundMeScreen.createPage');

		if (aroundMeScreen.page == 6) {
			user.connectionIdList = [];
		}
		var pages;

		for (var j = 0, length1 = members.length; j < length1; j++) {
			pages = members[j];
			for (var i = 1, length = pages.length; i <= length; i++) {
				var member = pages[i - 1];
				// For compatibility with member view !
				member._id = member.aboid;
				user.connectionIdList.push(member);
				
				if (i % 2 == 0) {
					member.className = "even";
				}
				else {
					member.className = "odd";
				}
				member.age = stringTable.code.old.replace('%s', member.age);
				member.online = member.status_online ? stringTable.code.online : stringTable.code.offline;
			}
		}

		var template = '<ul>\n\
				{{#items}}\n\
				<li class="{{className}}"  id="{{aboid}}" onclick="javascript:helper.addToHistory(\'aroundMe\');actuScreen.showProfile({{aboid}});return false;">\n\
					<span class="image"><img src={{photo}} alt=""/></span>\n\
					<span class="nickname">{{nickname}}</span>\n\
					<span class="infos">{{age}}</span>\n\
					<span class="town">{{town}}</span>\n\
					<span class="online">{{online}}</span>\n\
				</li>\n\
				{{/items}}\n\
			</ul>';

		var view = {
			items: user.connectionIdList
		}

		var html = Mustache.to_html(template, view);
		document.getElementById('aroundMeContainer').innerHTML = html;
		loader.hide();
	},
	displayMoreMembersButton: function(viewCode) {
		logger.error('aroundMeScreen.displayMoreMembersButton');
		var button = document.getElementById('aroundMeMore');
		if (button !== null) {
			button.style.display = 'block';
			button.onclick = function() {
				aroundMeScreen.page++;
				aroundMeScreen.loadData(viewCode);
			}
		}
	},
	hideMoreMembersButton: function() {
		logger.error('aroundMeScreen.hideMoreMembersButton');
		var button = document.getElementById('aroundMeMore');
		if (button !== null) {
			button.style.display = 'none';
		}
	}
}
