/**
 * inboxScreen class
 */
var inboxScreen = {
	page: 0,
	last: 0,
	container: null,
	newMessages:0,
	onActivate: function(data) {
		logger.debug('inboxScreen.onActivate');
		this.page = 1;
		this.container = document.getElementById("inboxContainer");
		if (this.container !== null) {
			this.loadData();
		}
		this.moreButton = document.getElementById("inboxMoreMails");
		if (this.moreButton !== null) {
			this.moreButton.addEventListener('click', this.clickOnMore, false);
		}
		document.getElementById('inboxNoResults').style.display = "none";
	},
	onDeactivate: function() {
		logger.debug('inboxScreen.onActivate');
		if (this.moreButton !== null) {
			this.moreButton.removeEventListener('click', this.clickOnMore, false);
		}
	},
	clickOnMore: function(event) {
		if (inboxScreen.page < inboxScreen.last) {
			inboxScreen.page++;
			inboxScreen.loadData();
		}
	},
	loadData: function() {
		logger.debug('inboxScreen.loadData');
		loader.show();
		var options = {
			method: 'GET',
			ws: 'msg.list',
			data: [
				'type=0',
				'page=' + this.page,
				'nb=20'
			]
		};
		ws.doRequest(options, this.successLoadData, this.errorLoadData);
	},
	successLoadData: function(httpReq) {
		logger.debug('inboxScreen.successLoadData');
		if (httpReq.responseText !== '') {
			// Eval response to transform json to an object
			try {
				var response = eval('(' + httpReq.responseText + ')');
				inboxScreen.newMessages = response.resultset.result.nb_messages_not_read;
			} catch(exception) {
				inboxScreen.errorLoadData('eval of httpReq.responsetext failed');
				return false;
			}

			if (typeof response.resultset.result != 'undefined') {
				if (response.resultset.result.navigate !== null) {
					inboxScreen.last = response.resultset.result.navigate.last;
				}
				inboxScreen.createPage(response.resultset.result.messages);
				return true;
			} else {
				inboxScreen.errorLoadData('response.resultset.result is undefined');
				return false;
			}
		} else {
			inboxScreen.errorLoadData('httpReq.responseText is empty');
			return false;
		}
	},
	errorLoadData: function(errorCode) {
		logger.debug('inboxScreen.errorLoadData');
		logger.error(errorCode);
		loader.hide();
		confirmation.alert("confirmationPopupText", stringTable.code.loadError);
	},
	createPage: function(messages) {
		logger.debug('inboxScreen.createPage');
		logger.debug(messages.length.toString());
		if (typeof messages != 'undefined' && messages.length > 0) {
			var dateToday = new Date();
			var dayToday = dateToday.getUTCDate().toString();
			var monthToday = (dateToday.getUTCMonth() + 1).toString();
			var yearToday = dateToday.getUTCFullYear().toString();

			for (var current = 0, length = messages.length; current < length; current++) {
				var convertedDate = new date(messages[current].date);
				if (convertedDate.day == dayToday && convertedDate.month == monthToday && convertedDate.year == yearToday) {
					messages[current].date = convertedDate.getHours('H');
				} else {
					messages[current].date = convertedDate.getDate('/');
				}
				messages[current].className = messages[current].read ? "read" : "unread";
				messages[current].age = stringTable.code.old.replace('%s', messages[current].age);
			}

			var template = '<ul>\n\
					{{#items}}\n\
					<li class="{{className}}"  id="{{ref}}" onclick="javascript:inboxScreen.mailClick(\'{{ref}}\', event);">\n\
						<input type="checkbox" name="mail_{{ref}}" value="{{ref}}"/>\n\
						<span class="date">{{date}}</span>\n\
						<span class="nickname">{{nickname}}</span>\n\
						<span class="infos">{{age}}, {{town}}</span>\n\
						<span class="title">{{header}}</span>\n\
					</li>\n\
					{{/items}}\n\
				</ul>';

			var view = {
				items: messages
			}
			var html = Mustache.to_html(template, view);
			if (inboxScreen.page == 1) {
				document.getElementById("inboxContainer").innerHTML = html;
			} else {
				document.getElementById("inboxContainer").innerHTML+= html;
			}
		} else if (typeof messages != 'undefined' && messages.length == 0) {
			document.getElementById('inboxNoResults').style.display = "block";
		}

		if ((inboxScreen.last == 0 || inboxScreen.page == inboxScreen.last) && inboxScreen.moreButton !== null) {
			inboxScreen.moreButton.style.display = "none";
		}
		loader.hide();
	},
	mailClick: function(id, event) {
		logger.debug('inboxScreen.mailClick');
		isInput = event.target.tagName.toLowerCase() == 'input';
		isCheckbox = event.target.type == 'checkbox';
		if (!isInput && !isCheckbox) {
			mailScreen.loadData(id);
//			helper.changePage('mail', id);
		}
	},
	selectAllMessages: function() {
		logger.debug('inboxScreen.selectAllMessages');
		var button = document.getElementById('checkAllMessagesButton');
		if (inboxScreen.allChecked === true) {
			helper.checkAllCheckboxes(this.container, false);
			inboxScreen.allChecked = false;
			button.innerHTML = stringTable.html.checkAllMessagesButton;
		} else {
			helper.checkAllCheckboxes(this.container, true);
			inboxScreen.allChecked = true;
			button.innerHTML = stringTable.html.uncheckAllMessagesButton;
		}
	},
	deleteMessages: function() {
		logger.debug('inboxScreen.deleteMessages');
		if (this.container !== null) {
			var checkboxes = helper.allCheckboxesChecked(this.container);
			var last = checkboxes.length - 1;
			for (var key in checkboxes) {
				inboxScreen.deleteMessage(checkboxes[key].value, key == last);
			}
		}
	},
	deleteMessage: function(msgref, last) {
		logger.debug('inboxScreen.deleteMessage');
		loader.show();
		var options = {
			method: 'GET',
			ws: 'msg.del',
			data: [
				'msgref=' + msgref
			]
		};
		ws.doRequest(options, function(httpReq) {
			inboxScreen.successDeleteMessage(httpReq, last);
		}, function(errorCode) {
			inboxScreen.errorDeleteMessage(errorCode, last);
		});
	},
	successDeleteMessage: function(httpReq, last) {
		logger.debug('inboxScreen.successDeleteMessage');
		if (last) {
			loader.hide();
			inboxScreen.loadData();
		}
	},
	errorDeleteMessage: function(errorCode, last) {
		logger.debug('inboxScreen.errorDeleteMessage');
		logger.error(errorCode);
		if (last) {
			loader.hide();
			inboxScreen.loadData();
		}
	}
}
