/**
 * User object to keep session
 */
var user =  {
	login: null,
	password: null,
	sessionId: null,
	searchGender: null,
	profile: null,
	rememberMe: false,
	connectionIdList: [],
	currentMemberViewingIndex: 0,
	myAboId: null,
	init: function() {
		logger.debug('user.init');
		var credentials = this.retrieveCredentials();
		var loginIsNotNull = typeof credentials.login !== 'undefined' && credentials.login !== null
		&& credentials.login !== '' && credentials.login !== 'null';
		var passwordIsNotNull = typeof credentials.password !== 'undefined' && credentials.password !== null
		&& credentials.password !== '' && credentials.password !== 'null';
		if (credentials && loginIsNotNull && passwordIsNotNull) {
			this.login = credentials.login;
			this.password = credentials.password;
			this.remember = true;
			actuScreen.firstTime = false;
			ws.authenticate(this.login, this.password, this.successAuthenticate, this.errorAuthenticate);
		} else {
			if (helper.isMiniViewMode()) {
				helper.changePage('widgetHome');
			} else {
				helper.changePage('login');
			}
		}
	},
	checkNewMessages: function() {
		inboxScreen.loadData();
		return inboxScreen.newMessages;
	},
	setCredentials: function(login, password) {
		logger.debug('user.setCredentials');
		this.login = login;
		this.password = password;
	},
	retrieveCredentials: function() {
		logger.debug('user.retrieveCredentials');
		var credentials = {
			"login": widget.preferenceForKey('meetic_login'),
			"password": widget.preferenceForKey('meetic_password')
		};
		return credentials;
	},
	// Save credentials into local storage
	saveCredentials: function() {
		logger.debug('user.saveCredentials');
		if (this.login !== null && this.password !== null && this.rememberMe) {
			widget.setPreferenceForKey(this.login, 'meetic_login');
			widget.setPreferenceForKey(this.password, 'meetic_password');
		}
	},
	reset: function() {
		logger.debug('user.reset');
		user.logout();
		widget.setPreferenceForKey(null, 'meetic_login');
		widget.setPreferenceForKey(null, 'meetic_password');
		user.login = null;
		user.password = null;
		user.sessionId = null;
		user.rememberMe = false;
		user.profile = null;
	},
	isConnected: function() {
		logger.debug('user.isConnected');
		return (this.sessionId != null);
	},
	successAuthenticate: function(httpReq) {
		logger.debug('user.successAuthenticate');
		if (httpReq.responseText !== '') {
			try {
				var response = eval('(' + httpReq.responseText + ')');
			} catch(exception) {
				logger.error('Unable to convert webservice response.');
				return false;
			}

			if (typeof response.resultset.result != 'undefined') {
				logger.debug('Session id => ' + response.resultset.result.ssid);
				user.sessionId = response.resultset.result.ssid;
				// Set remember me
				user.rememberMe =  true;
				// Store
				user.setCredentials(user.login, user.password);
				user.getAboId();
			} else {
				user.errorAuthenticate('Unable to get session id');
			}
		} else {
			user.errorAuthenticate('reponse is empty');
		}
	},
	errorAuthenticate: function(errorCode) {
		logger.debug('user.errorAuthenticate');
		logger.error(errorCode);
		if (helper.isMiniViewMode()) {
			helper.changePage('widgetHome');
		} else {
			helper.changePage('login');
		}
	},
	getAboId: function(){
		logger.debug("getAboId");
		var options = {
			method: 'GET',
			ws: 'myaccount.displaypersonaldata',
			data: []
		}

		ws.doRequest(options, user.getAboIdSuccessCallback, user.getAboIdErrorCallback);
	},
	loadUserProfile: function() {
		logger.debug('user.loadUserProfile');
		var options = {
			method: 'GET',
			ws: 'myprofile.display',
			data: []
		}
		ws.doRequest(options, user.successLoadUserProfile, user.errorLoadUserProfile);
	},
	getAboIdSuccessCallback: function(httpReq) {
		if (httpReq.responseText !== '') {
			try {
				var response = eval('(' + httpReq.responseText + ')');
				user.myAboId = response.resultset.result.response.abo_id;
				user.loadUserProfile();
			} catch(exception) {
				user.errorLoadUserProfile('eval of httpReq.responsetext failed');
				return false;
			}
		}
	},
	getAboIdErrorCallback: function(httpReq) {
		user.myAboId = null;
		logger.debug('user.errorGetAboId');
		loader.hide();
		return true;
	},
	successLoadUserProfile: function(httpReq) {
		logger.debug('user.successLoadUserProfile');
		if (httpReq.responseText !== '') {
			try {
				var response = eval('(' + httpReq.responseText + ')');
				// init user search gender
				user.searchGender = response.resultset.result.my_search_gender;
			//user.getAboId();
			} catch(exception) {
				user.errorLoadUserProfile('eval of httpReq.responsetext failed');
				return false;
			}
			if (typeof response.resultset.result != 'undefined') {
				user.profile = response.resultset.result;
				if (helper.isMiniViewMode()) {
					helper.changePage('widgetHome');
				} else {
					helper.changePage(DEFAULT_SCREEN);
				}
				loader.hide();
			} else {
				//loginScreen.errorAuthenticate('wsResponseUnavailable');
				user.errorLoadUserProfile('response.resultset.result is undefined');
				return false;
			}
		} else {
			//loginScreen.errorAuthenticate('wsResponseUnavailable');
			user.errorLoadUserProfile('httpReq.responseText is empty');
			return false;
		}
	},
	errorLoadUserProfile: function (errorCode) {
		logger.debug('user.errorLoadUserProfile');
		logger.error(errorCode);
		loader.hide();
	},
	logout: function() {
		logger.debug('user.logout');
		var options = {
			method: 'GET',
			ws: 'authent.logout',
			data: []
		}
		ws.doRequest(options, user.successLogout, user.errorLogout);
	},
	successLogout: function(httpReq) {
		logger.debug('user.successLogout');
		actuScreen.firstTime = true;
	},
	errorLogout: function(errorCode) {
		logger.debug('user.errorLogout');
		logger.error(errorCode);
	}
}
